# QURI VM

QURI VM is an open source library for resource estimation and execution of FTQC algorithms.

QURI VM aims to facilitate research into FTQC algorithms by separating and abstracting the user code describing the FTQC algorithms from the backends. Users can easily switch backends to perform resource estimation for different architectures and devices, and even run on simulators, using the same code.

## Installation

QURI VM requires Python 3.10 or later.

Use `pip` to install QURI VM.

```shell
pip install quri-vm
```

## Documentation

Documentation to QURI VM is available at [QURI SDK documentation site](https://quri-sdk.qunasys.com).

## Release notes

See [Release page](https://github.com/QunaSys/quri-vm/releases) on GitHub.

## Authors

QURI VM developed and maintained by [QunaSys Inc.](https://qunasys.com/en/). All contributors can be viewed on [GitHub](https://github.com/QunaSys/quri-vm/graphs/contributors).

## License

QURI VM is licensed under [MIT License](https://github.com/QunaSys/quri-vm/blob/main/LICENSE).
